Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(436)

Unified Diff: ui/views/animation/ink_drop_ripple_observer.h

Issue 1937103003: Rename of InkDropAnimation classes to InkDropRipple. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Removed test_ink_drop_animation_observer.h from views.gyp and doc update. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/animation/ink_drop_ripple.cc ('k') | ui/views/animation/ink_drop_ripple_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/animation/ink_drop_ripple_observer.h
diff --git a/ui/views/animation/ink_drop_animation_observer.h b/ui/views/animation/ink_drop_ripple_observer.h
similarity index 71%
rename from ui/views/animation/ink_drop_animation_observer.h
rename to ui/views/animation/ink_drop_ripple_observer.h
index 831a6be06b3b6065eb4856ef342d3569a6daa905..b294b3ae95ca87c4cdd3d813dbf992dcfb90a290 100644
--- a/ui/views/animation/ink_drop_animation_observer.h
+++ b/ui/views/animation/ink_drop_ripple_observer.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef UI_VIEWS_ANIMATION_INK_DROP_ANIMATION_OBSERVER_H_
-#define UI_VIEWS_ANIMATION_INK_DROP_ANIMATION_OBSERVER_H_
+#ifndef UI_VIEWS_ANIMATION_INK_DROP_RIPPLE_OBSERVER_H_
+#define UI_VIEWS_ANIMATION_INK_DROP_RIPPLE_OBSERVER_H_
#include <string>
@@ -14,8 +14,8 @@
namespace views {
-// Observer to attach to an InkDropAnimation.
-class VIEWS_EXPORT InkDropAnimationObserver {
+// Observer to attach to an InkDropRipple.
+class VIEWS_EXPORT InkDropRippleObserver {
public:
// An animation for the given |ink_drop_state| has started.
virtual void AnimationStarted(InkDropState ink_drop_state) = 0;
@@ -29,13 +29,13 @@ class VIEWS_EXPORT InkDropAnimationObserver {
InkDropAnimationEndedReason reason) = 0;
protected:
- InkDropAnimationObserver() = default;
- virtual ~InkDropAnimationObserver() = default;
+ InkDropRippleObserver() = default;
+ virtual ~InkDropRippleObserver() = default;
private:
- DISALLOW_COPY_AND_ASSIGN(InkDropAnimationObserver);
+ DISALLOW_COPY_AND_ASSIGN(InkDropRippleObserver);
};
} // namespace views
-#endif // UI_VIEWS_ANIMATION_INK_DROP_ANIMATION_OBSERVER_H_
+#endif // UI_VIEWS_ANIMATION_INK_DROP_RIPPLE_OBSERVER_H_
« no previous file with comments | « ui/views/animation/ink_drop_ripple.cc ('k') | ui/views/animation/ink_drop_ripple_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698